summaryrefslogtreecommitdiffstats
path: root/ldap/admin
diff options
context:
space:
mode:
Diffstat (limited to 'ldap/admin')
-rw-r--r--ldap/admin/lib/dsalib_updown.c14
-rw-r--r--ldap/admin/src/Base.def2
-rw-r--r--ldap/admin/src/configure_instance.cpp12
-rw-r--r--ldap/admin/src/create_instance.c4
-rwxr-xr-xldap/admin/src/logconv.pl4
-rwxr-xr-xldap/admin/src/scripts/template-cl-dump.pl9
-rw-r--r--ldap/admin/src/scripts/template-dsml-activate.pl2
-rwxr-xr-xldap/admin/src/scripts/template-repl-monitor.pl11
-rwxr-xr-xldap/admin/src/updatedsgw2
9 files changed, 35 insertions, 25 deletions
diff --git a/ldap/admin/lib/dsalib_updown.c b/ldap/admin/lib/dsalib_updown.c
index b737406d..80abe9b9 100644
--- a/ldap/admin/lib/dsalib_updown.c
+++ b/ldap/admin/lib/dsalib_updown.c
@@ -514,7 +514,7 @@ StartNetscapeProgram()
CmdFile = fopen(line, "r");
if (!CmdFile)
{
- PR_snprintf(ErrorString, sizeof(ErrorString), "Error:Tried to start Netscape server %s "
+ PR_snprintf(ErrorString, sizeof(ErrorString), "Error:Tried to start server %s "
": Could not open the startup script %s :Error %d. Please "
"run startsrv.bat from the server's root directory.",
ds_get_server_name(), line, errno);
@@ -525,7 +525,7 @@ StartNetscapeProgram()
ZeroMemory(cmd, sizeof(cmd));
if (!fread(cmd, 1, BIG_LINE, CmdFile))
{
- PR_snprintf(ErrorString, sizeof(ErrorString), "Error:Tried to start Netscape server %s "
+ PR_snprintf(ErrorString, sizeof(ErrorString), "Error:Tried to start server %s "
": Could not read the startup script %s :Error %d. Please "
"run startsrv.bat from the server's root directory.",
ds_get_server_name(), line, errno);
@@ -542,7 +542,7 @@ StartNetscapeProgram()
if (!CreateProcess(NULL, cmd, NULL, NULL, FALSE,
0, NULL, NULL, &siStartInfo, &piProcInfo))
{
- PR_snprintf(ErrorString, sizeof(ErrorString), "Error:Tried to start Netscape server %s "
+ PR_snprintf(ErrorString, sizeof(ErrorString), "Error:Tried to start server %s "
": Could not start up the startup script %s :Error %d. Please "
"run startsrv.bat from the server's root directory.",
ds_get_server_name(), line, GetLastError());
@@ -565,7 +565,7 @@ StopNetscapeProgram()
hEvent = CreateEvent(NULL, TRUE, FALSE, servid);
if(!SetEvent(hEvent))
{
- PR_snprintf(ErrorString, sizeof(ErrorString), "Tried to stop existing Netscape server %s"
+ PR_snprintf(ErrorString, sizeof(ErrorString), "Tried to stop existing server %s"
": Could not signal it to stop :Error %d",
servid, GetLastError());
ds_send_error(ErrorString, 0);
@@ -588,7 +588,7 @@ StopNetscapeService()
if (schService == NULL)
{
- PR_snprintf(ErrorString, sizeof(ErrorString), "Tried to open Netscape service"
+ PR_snprintf(ErrorString, sizeof(ErrorString), "Tried to open service"
" %s: Error %d (%s). Please"
" stop the server from the Services Item in the Control Panel",
serviceName, GetLastError(), ds_system_errmsg());
@@ -613,7 +613,7 @@ StopNetscapeService()
}
else if (Error != ERROR_SERVICE_NOT_ACTIVE)
{
- PR_snprintf(ErrorString, sizeof(ErrorString), "Tried to stop Netscape service"
+ PR_snprintf(ErrorString, sizeof(ErrorString), "Tried to stop service"
" %s: Error %d (%s)."
" Please stop the server from the Services Item in the"
" Control Panel", serviceName, Error, ds_system_errmsg());
@@ -639,7 +639,7 @@ StartNetscapeService()
{
CloseServiceHandle(schService);
PR_snprintf(ErrorString, sizeof(ErrorString),"Tried to start"
- " the Netscape service %s: Error %d. Please"
+ " the service %s: Error %d. Please"
" start the server from the Services Item in the Control Panel",
serviceName, GetLastError());
ds_send_error(ErrorString, 0);
diff --git a/ldap/admin/src/Base.def b/ldap/admin/src/Base.def
index 38fbd9f1..414f647b 100644
--- a/ldap/admin/src/Base.def
+++ b/ldap/admin/src/Base.def
@@ -4,7 +4,7 @@
; All rights reserved.
; END COPYRIGHT BLOCK
;
-DESCRIPTION 'Netscape Setup SDK Dynamic perl module'
+DESCRIPTION 'Setup SDK Dynamic perl module'
CODE SHARED READ EXECUTE
DATA SHARED READ WRITE
EXPORTS
diff --git a/ldap/admin/src/create_instance.c b/ldap/admin/src/create_instance.c
index a7ead0ae..3906bca8 100644
--- a/ldap/admin/src/create_instance.c
+++ b/ldap/admin/src/create_instance.c
@@ -3892,7 +3892,7 @@ ds_gen_gw_conf(char *sroot, char *cs_path, server_config_s *cf, int conf_type)
}
/* Write out the appropriate values */
- fprintf(f, "# Used by Netscape Directory Server Gateway\n");
+ fprintf(f, "# Used by Directory Server Gateway\n");
fprintf(f, "baseurl\t\"ldap://%s:%s/", cf->servname, cf->servport);
fputs_escaped(cf->suffix, f);
fputs("\"\n\n",f);
@@ -4008,7 +4008,7 @@ ds_gen_orgchart_conf(char *sroot, char *cs_path, server_config_s *cf)
/* Write out the appropriate values */
fprintf(f, "#############\n#\n#\n");
- fprintf(f, "# Configuration file for Netscape Directory Server Org Chart\n");
+ fprintf(f, "# Configuration file for Directory Server Org Chart\n");
fprintf(f, "# ----------------------------------------------------------\n#\n#\n");
fprintf(f, "#############\n\n\n#\n");
fprintf(f, "# Blank lines in this file, as well as lines that\n");
diff --git a/ldap/admin/src/logconv.pl b/ldap/admin/src/logconv.pl
index 0ce0b789..33b416ff 100755
--- a/ldap/admin/src/logconv.pl
+++ b/ldap/admin/src/logconv.pl
@@ -42,7 +42,7 @@ while ($sn <= $#ARGV)
}
elsif ("$ARGV[$sn]" eq "-v")
{
- print "Netscape Access Log Analyzer v$logversion\n";;
+ print "Access Log Analyzer v$logversion\n";;
exit (0);
}
elsif ("$ARGV[$sn]" eq "-V")
@@ -88,7 +88,7 @@ if ($sizeCount eq "all"){$sizeCount = "100000";}
# #
#######################################
-print "\nNetscape Access Log Analyzer $logversion\n";
+print "\nAccess Log Analyzer $logversion\n";
print "\nCommand : logconv.pl @ARGV\n\n";
$dirmgr = "0";
diff --git a/ldap/admin/src/scripts/template-cl-dump.pl b/ldap/admin/src/scripts/template-cl-dump.pl
index 8fad1505..b2d682f7 100755
--- a/ldap/admin/src/scripts/template-cl-dump.pl
+++ b/ldap/admin/src/scripts/template-cl-dump.pl
@@ -6,6 +6,11 @@
# END COPYRIGHT BLOCK
################################################################################
#
+# BEGIN COPYRIGHT BLOCK
+# Copyright (C) 2005 Red Hat, Inc.
+# All rights reserved.
+# END COPYRIGHT BLOCK
+#
# FILE: cl-dump.pl
#
# SYNOPSIS:
@@ -16,7 +21,7 @@
# cl-dump.pl -i changelog-ldif-file-with-base64encoding [-o output-file] [-c]\n";
#
# DESCRIPTION:
-# Dump and decode Netscape Directory Server replication change log
+# Dump and decode Directory Server replication change log
#
# OPTIONS:
#
@@ -74,7 +79,7 @@ use MIME::Base64; # Decode
# Global variables
-$version = "Netscape Directory Server Changelog Dump - Version 1.0";
+$version = "Directory Server Changelog Dump - Version 1.0";
#main
{
diff --git a/ldap/admin/src/scripts/template-dsml-activate.pl b/ldap/admin/src/scripts/template-dsml-activate.pl
index 3bd159ad..7f0d93b2 100644
--- a/ldap/admin/src/scripts/template-dsml-activate.pl
+++ b/ldap/admin/src/scripts/template-dsml-activate.pl
@@ -155,7 +155,7 @@ EOF
print STDERR "adding necessary entry to $file.\n";
print <<EOF;
<?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE vs SYSTEM "file:${SERVERROOT}/bin/https/dtds/nes-webapps_6_1.dtd">
+<!DOCTYPE vs SYSTEM "file:${SERVERROOT}/bin/https/dtds/nes-webapps_6_2.dtd">
<vs>
<web-app uri="/axis" dir="${SERVERROOT}{{SEP}}clients{{SEP}}dsmlgw" enable="true"/>
diff --git a/ldap/admin/src/scripts/template-repl-monitor.pl b/ldap/admin/src/scripts/template-repl-monitor.pl
index 3a356e4e..3a79ac69 100755
--- a/ldap/admin/src/scripts/template-repl-monitor.pl
+++ b/ldap/admin/src/scripts/template-repl-monitor.pl
@@ -6,6 +6,11 @@
# END COPYRIGHT BLOCK
##############################################################################
#
+# BEGIN COPYRIGHT BLOCK
+# Copyright (C) 2005 Red Hat, Inc.
+# All rights reserved.
+# END COPYRIGHT BLOCK
+#
# FILE: repl-monitor.pl
#
# SYNOPSIS:
@@ -28,7 +33,7 @@
# parameters, the server alias, and the thresholds for different colors
# when display the time lags between consumers and master.
# If the Admin Server is running on Windows, the configuration-file
-# name may have format "D:/Netscape/replmon.conf".
+# name may have format "D:/opt/replmon.conf".
#
# The connection parameter section consists of the section name
# followed by one of more connection parameter entries:
@@ -135,7 +140,7 @@ use Time::Local; # to convert GMT Z strings to localtime
#
# Global variables
#
-$product = "Netscape Directory Server Replication Monitor";
+$product = "Directory Server Replication Monitor";
$version = "Version 1.0";
#
# ldap servers given or discovered from the replication agreements:
@@ -907,7 +912,7 @@ sub print_html_header
print "<table border=0 cellspacing=0 cellpadding=10 width=100% class=bgColor1>\n";
print "<tr><td><font class=text8>$now</font></td>\n";
print "<td align=center class=page-title><font color=#0099CC>";
- print "Netscape Directory Server Replication Status</font>\n";
+ print "Directory Server Replication Status</font>\n";
if ($opt_u) {
print "<br><font class=text8>(This page updates every $interval seconds)</font>\n";
diff --git a/ldap/admin/src/updatedsgw b/ldap/admin/src/updatedsgw
index d740f319..2d154396 100755
--- a/ldap/admin/src/updatedsgw
+++ b/ldap/admin/src/updatedsgw
@@ -27,7 +27,7 @@ if (!$nshome ) {
print " -t suffix\t\tthe new ESCAPED suffix of the directory server\n";
print " -d dirmgrdn\t\tthe old manager dn of the directory server\n";
print " -e dirmgrdn\t\tthe new manager dn of the directory server\n";
- print "\nexample:\n " . $0 . " -n /home/servers/ds71/ -h gargoyle:1974 -i brooklyn -s \"dc=example,dc=com\" -t \"o%3Dbrandx.com\" -d \"cn=directory manager\" -e \"cn=directory guru\"\n";
+ print "\nexample:\n " . $0 . " -n /home/servers/ds71/ -h gargoyle:1974 -i brooklyn -s \"dc=example,dc=com\" -t \"o%3Dredhat.com\" -d \"cn=directory manager\" -e \"cn=directory guru\"\n";
exit;
}
diff --git a/ldap/admin/src/configure_instance.cpp b/ldap/admin/src/configure_instance.cpp
index f2d6b70d..1aaa0c60 100644
--- a/ldap/admin/src/configure_instance.cpp
+++ b/ldap/admin/src/configure_instance.cpp
@@ -10,7 +10,7 @@
** configure_instance.cpp
**
** DESCRIPTION:
** Netscape Directory Server Configuration Program
**
** NOTES:
** Derived from the original ux-config.cc
@@ -621,7 +621,7 @@ getAdminSIEDN(const char *dsSIEDN, const char *hostname, NSString& adminSIEDN)
ldap_value_free(rdnList);
adminSIEDN = NSString("cn=admin-serv-") + editablehostname +
- ", cn=Netscape Administration Server, " + baseDN;
+ ", cn=Fedora Administration Server, " + baseDN;
delete [] editablehostname;
free(baseDN);
@@ -901,14 +901,14 @@ create_roledit_extension(Ldap* ldap)
ldapEntry.setAttribute("objectclass", DEFAULT_GLOBAL_PREFS_OBJECT);
ldapEntry.setAttribute("ou", DEFAULT_GLOBAL_PREFS);
ldapEntry.setAttribute("aci", DEFAULT_GLOBAL_PREFS_ACI);
- ldapEntry.setAttribute("description", "Default branch for Netscape Server Products Global Preferences");
+ ldapEntry.setAttribute("description", "Default branch for Fedora Server Products Global Preferences");
// dsLogMessage("Info", "Slapd", "Updating global preferences for console role editor extensions");
err = ldapEntry.insert(globalPref);
}
else
{
ldapEntry.setAttribute("aci", DEFAULT_GLOBAL_PREFS_ACI);
- ldapEntry.setAttribute("description", "Default branch for Netscape Server Products Global Preferences");
+ ldapEntry.setAttribute("description", "Default branch for Fedora Server Products Global Preferences");
// dsLogMessage("Info", "Slapd", "Updating global preferences for console role editor extensions");
err = ldapEntry.replace(globalPref);
}
@@ -970,7 +970,7 @@ create_ss_dir_tree(const char *hostname, NSString &sieDN)
if (code != OKAY)
{
dsLogMessage(SETUP_LOG_FATAL, "Slapd",
- "ERROR: failed to register Directory server as a Netscape server (%d)",
+ "ERROR: failed to register Directory server as a Fedora server (%d)",
code);
return code;
}
@@ -1091,7 +1091,7 @@ create_console_script()
ofs << "#!/bin/sh" << endl;
ofs << "#" << endl;
- ofs << "# This script will invoke the Netscape Console" << endl;
+ ofs << "# This script will invoke the Fedora Management Console" << endl;
ofs << "#" << endl;
// see if there are any other .jar or .zip files in the java directory
// and add them to our class path too
@@ -10,7 +10,7 @@
**
** DESCRIPTION:
-** Netscape Directory Server Configuration Program
+** Fedora Directory Server Configuration Program
**
** NOTES: